aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorVidhu Kant Sharma <vidhukant@protonmail.ch>2022-02-17 21:43:37 +0530
committerVidhu Kant Sharma <vidhukant@protonmail.ch>2022-02-17 21:43:37 +0530
commit8824c264c6d4230d353546ee69036ad41d4ec8cc (patch)
tree2ed73df5d02b4bdfe087f3943353efad015f57f8
parentd04c7f9c60ba5955f3d96ec6ae7397788dcbc3df (diff)
removed conflicts due to module name change
-rw-r--r--anime/anime.go6
-rw-r--r--anime/anime.structs.go2
-rw-r--r--anime/general.structs.go2
-rw-r--r--anime/ranking.structs.go2
-rw-r--r--anime/request_handler.go2
-rw-r--r--anime/search.structs.go2
-rw-r--r--anime/seasonal.structs.go2
-rw-r--r--anime/suggestedanime.structs.go2
8 files changed, 10 insertions, 10 deletions
diff --git a/anime/anime.structs.go b/anime/anime.structs.go
index 1599e6d..c7b4f00 100644
--- a/anime/anime.structs.go
+++ b/anime/anime.structs.go
@@ -1,4 +1,4 @@
-/* mal2go - MyAnimeList V2 API wrapper for Go
+/* MAL2Go - MyAnimeList V2 API wrapper for Go
* Copyright (C) 2022 Vidhu Kant Sharma <vidhukant@protonmail.ch>
* This program is free software: you can redistribute it and/or modify
diff --git a/anime/general.structs.go b/anime/general.structs.go
index 5df1357..47309c3 100644
--- a/anime/general.structs.go
+++ b/anime/general.structs.go
@@ -1,4 +1,4 @@
-/* mal2go - MyAnimeList V2 API wrapper for Go
+/* MAL2Go - MyAnimeList V2 API wrapper for Go
* Copyright (C) 2022 Vidhu Kant Sharma <vidhukant@protonmail.ch>
* This program is free software: you can redistribute it and/or modify
diff --git a/anime/ranking.structs.go b/anime/ranking.structs.go
index 28ae860..03a4589 100644
--- a/anime/ranking.structs.go
+++ b/anime/ranking.structs.go
@@ -1,4 +1,4 @@
-/* mal2go - MyAnimeList V2 API wrapper for Go
+/* MAL2Go - MyAnimeList V2 API wrapper for Go
* Copyright (C) 2022 Vidhu Kant Sharma <vidhukant@protonmail.ch>
* This program is free software: you can redistribute it and/or modify
diff --git a/anime/request_handler.go b/anime/request_handler.go
index 809ca07..fe4f874 100644
--- a/anime/request_handler.go
+++ b/anime/request_handler.go
@@ -1,4 +1,4 @@
-/* mal2go - MyAnimeList V2 API wrapper for Go
+/* MAL2Go - MyAnimeList V2 API wrapper for Go
* Copyright (C) 2022 Vidhu Kant Sharma <vidhukant@protonmail.ch>
* This program is free software: you can redistribute it and/or modify
diff --git a/anime/search.structs.go b/anime/search.structs.go
index e59bb44..ff79a4b 100644
--- a/anime/search.structs.go
+++ b/anime/search.structs.go
@@ -1,4 +1,4 @@
-/* mal2go - MyAnimeList V2 API wrapper for Go
+/* MAL2Go - MyAnimeList V2 API wrapper for Go
* Copyright (C) 2022 Vidhu Kant Sharma <vidhukant@protonmail.ch>
* This program is free software: you can redistribute it and/or modify
diff --git a/anime/seasonal.structs.go b/anime/seasonal.structs.go
index 06bda42..af5f96c 100644
--- a/anime/seasonal.structs.go
+++ b/anime/seasonal.structs.go
@@ -1,4 +1,4 @@
-/* mal2go - MyAnimeList V2 API wrapper for Go
+/* MAL2Go - MyAnimeList V2 API wrapper for Go
* Copyright (C) 2022 Vidhu Kant Sharma <vidhukant@protonmail.ch>
* This program is free software: you can redistribute it and/or modify
diff --git a/anime/suggestedanime.structs.go b/anime/suggestedanime.structs.go
index a7b3a60..13e5afc 100644
--- a/anime/suggestedanime.structs.go
+++ b/anime/suggestedanime.structs.go
@@ -1,4 +1,4 @@
-/* mal2go - MyAnimeList V2 API wrapper for Go
+/* MAL2Go - MyAnimeList V2 API wrapper for Go
* Copyright (C) 2022 Vidhu Kant Sharma <vidhukant@protonmail.ch>
* This program is free software: you can redistribute it and/or modify
diff --git a/anime/anime.go b/anime/anime.go
index 969b04c..3330c16 100644
--- a/anime/anime.go
+++ b/anime/anime.go
@@ -1,4 +1,4 @@
/* mal2go - MyAnimeList V2 API wrapper for Go
* Copyright (C) 2022 Vidhu Kant Sharma <vidhukant@protonmail.ch>
* This program is free software: you can redistribute it and/or modify
@@ -21,8 +21,8 @@ import (
"errors"
"fmt"
"strconv"
- e "github.com/MikunoNaka/mal2go/errhandlers"
- u "github.com/MikunoNaka/mal2go/util"
+ e "github.com/MikunoNaka/MAL2Go/errhandlers"
+ u "github.com/MikunoNaka/MAL2Go/util"
)
const BASE_URL string = "https://api.myanimelist.net/v2/anime"
@@ -1,4 +1,4 @@
-/* mal2go - MyAnimeList V2 API wrapper for Go
+/* MAL2Go - MyAnimeList V2 API wrapper for Go
* Copyright (C) 2022 Vidhu Kant Sharma <vidhukant@protonmail.ch>
* This program is free software: you can redistribute it and/or modify